%ExampleAcoustic.m sample program
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                               %
%       CHANNEL IMPULSE RESPONSE, PULSED SIGNAL RESPONSE        %
%                    & FREQUENCY RESPONSE (Acoustic)                      %
%        by E. Amador (emmanuel.amador@insa-rennes.fr)          %
%                         IETR/DGA                              %
%                                                               %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear

global Lt c R N POS alpha

tic
c = 340;%
Lt = 2; %Time-window length in seconds
nbre_elements = 1; %number of radiating elements
dmax = c*Lt; %maximal distance

%loading the Position matrix from the image generator
filename = sprintf('%delem_%ds1s8.mat',nbre_elements,round(Lt)); 
load(filename)

%Pulsed signal
tau=1; %length of the pulse in seconds
f0=440; %monochromatic pulse frequency
Fs=44100
N=Fs*Lt %number of points for the chosen time-window (Lt)
t=0:Lt/(N-1):Lt; %time
x=0:1/((N-1)/Lt):tau;
%s=sin(2*pi*f0*x); %pulsed signal
hello=wavread('hello.wav');
s=hello(:,1);

%Loss coefficient on the walls
R = 1-0.08;

%linear attenaution
alpha = 3e-8;

%Reception point rectangular coordinates
X_1 = 3;
Y_1 = 2;
Z_1 = 1;

[SCIR] = CIR(X_1,Y_1,Z_1);

%Convolution of the CIRs with the chosen pulsed signal
disp('Convolution...')
Si = conv(SCIR,s);

Signalfinal = Si(1:N);

soundsc((Signalfinal),Fs)

toc

%Frequency response
disp('FFT...')
Fs = N/Lt; %sampling frequency
T = 1/Fs;                     % sample length
L = N;                  %Number of points
tt = (0:L-1)*T;                % time...

NFFT = 2^nextpow2(N); % Next power of 2 from length of y
Y = fft((SCIR),NFFT);

f = Fs/2*linspace(0,1,NFFT/2);

% Three axis frequency response
FFTs = abs(Y(1:NFFT/2))/NFFT/2;

freq = f;

toc

% figure
figure(1)
subplot(2,1,1)
plot(t,SCIR)
xlim([0 1])
title('(a) CIR')
grid on
xlabel('temps [s]')
ylabel('A')

subplot(2,1,2)
plot(freq,20*log10(FFTs))
title('(b) FFT')
xlim([0 1000])
grid on
xlabel('frequence [Hz]')
ylabel('dB')

figure(2)
ddd=10*log10(SCIR.^2/max(SCIR.^2))
plot(t(1:8:end),ddd(1:8:end),t(1:8:end),-60*ones(length(t(1:8:end)),1))
xlabel('temps [s]')
ylabel('Puissance normalisee [dB]')





figure(3)

subplot(2,1,1)
plot(t(1:length(s)),s)
xlim([0 1])
title('(a) Signal')
grid on
xlabel('temps [s]')
ylabel('A')

subplot(2,1,2)
plot(t,Signalfinal)
xlim([0 1])
title('(b) CONV')
grid on
xlabel('temps [s]')
ylabel('A')
